; Fur rel 0.03.3
; Created by Graechan
; Comments directed to http://gimpchat.com or http://gimpscripts.com
;
; License: GPLv3
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;    GNU General Public License for more details.
;
;    To view a copy of the GNU General Public License
;    visit: http://www.gnu.org/licenses/gpl.html
;
;
; ------------
;| Change Log |
; ------------ 
; Rel 0.01 - Initial Release
; Rel 0.02 - Changed text in gimpressionist to "Furry" instead of "furry"
; Rel 0.03 - Added option to use the existing colors and a softness setting 
(define (script-fu-fur-logo 
                                      img-width
                                      img-height
                                      text
									  letter-spacing
									  line-spacing
									  font-in 
                                      font-size
									  tint-color
									  motle-color
									  motle-size
							          motle
									  blur-radius
                                      bkg-type 
                                      pattern
                                      bkg-color
									  gradient
									  conserve)
									  
  (let* ((width img-width)
         (height img-height)
         (offx 0)
         (offy 0)
         (image (car (gimp-image-new img-width img-height RGB)))
         (border (/ font-size 3))
		 (font (if (> (string-length font-in) 0) font-in (car (gimp-context-get-font))))
         (layer (car (gimp-text-fontname image -1 0 0 text border TRUE font-size PIXELS font)))
         (text-width (car (gimp-drawable-width layer)))
         (text-height (car (gimp-drawable-height layer)))
		 (final-width 0)
		 (final-height 0)
		 (bkg-layer 0))
		 
    (gimp-context-push)
	(gimp-context-set-foreground '(0 0 0))
	(gimp-context-set-background '(255 255 255))
	
;;;;Adjust the text on line
	(gimp-text-layer-set-justification layer 2)
	(gimp-text-layer-set-letter-spacing layer letter-spacing)
	(gimp-text-layer-set-line-spacing layer line-spacing)
	(set! text-width (car (gimp-drawable-width layer)))
    (set! text-height (car (gimp-drawable-height layer)))
	
;;;;set the new Image size
	(if (> text-width img-width) (set! width text-width))           
    (if (> text-height img-height) (set! height text-height))
	(set! final-width width)
	(set! final-height height)

;;;;resize the image	
	(gimp-image-resize image width height 0 0)

;;;;centre the text layer	
    (set! offx (/ (- width text-width) 2))
    (set! offy (/ (- height text-height) 2))    
    (gimp-layer-set-offsets layer offx offy)	

;;;;set the text clolor    
    (gimp-selection-layer-alpha layer)
	(gimp-edit-fill layer FOREGROUND-FILL)
	(gimp-selection-none image)

;;;;create the fur	
    (script-fu-fur image layer 0 tint-color motle-color motle-size motle blur-radius FALSE TRUE)
	(set! layer (car (gimp-image-get-active-layer image)))	
    	
;;;;create the background layer    
	(if (> bkg-type 0) (begin
	(set! bkg-layer (car (gimp-layer-new image width height RGBA-IMAGE "Background" 100 NORMAL-MODE)))
    (if (= conserve FALSE) (begin
	(gimp-image-add-layer image bkg-layer (+ (car (gimp-image-get-layer-position image layer)) 1)))
	(gimp-image-add-layer image bkg-layer (+ (car (gimp-image-get-layer-position image layer)) 2)))
	(gimp-context-set-pattern pattern)
	(gimp-context-set-background bkg-color)
	(gimp-context-set-gradient gradient)
	(if (= bkg-type 1) (gimp-drawable-fill bkg-layer PATTERN-FILL))		
    (if (= bkg-type 3) (gimp-drawable-fill bkg-layer BACKGROUND-FILL))	
    (if (= bkg-type 2) (gimp-edit-blend bkg-layer CUSTOM-MODE NORMAL-MODE  GRADIENT-LINEAR 100 0 REPEAT-NONE FALSE FALSE 3 0.2 TRUE 0 0 width height))));; GRADIENT-LINEAR ; GRADIENT-CONICAL-SYMMETRIC
              
    (gimp-image-set-active-layer image layer)
	(gimp-layer-resize-to-image-size layer)
	
;;;;tidy the layers
    (if (= conserve FALSE) (gimp-image-remove-layer image layer))
    (if (and (= conserve FALSE) (> bkg-type 0)) (set! layer (car (gimp-image-merge-visible-layers image EXPAND-AS-NECESSARY))))	
	(gimp-drawable-set-name (car (gimp-image-get-active-layer image)) text)
    
	(gimp-context-pop)
    (gimp-display-new image)
	
    )
  )
  


(define (script-fu-fur image layer
                               fur-color
							   tint-color
							   motle-color
							   motle-size
							   motle
							   blur-radius
							   keep-selection-in
							   conserve)
	(gimp-context-push)
    (gimp-image-undo-group-start image)
	

 (let* (
            (width (car (gimp-image-width image)))
			(height (car (gimp-image-height image)))
			(fur-layer 0)
			(final-width width)
			(final-height height)
			(area (* 1000 1000))
			(alpha (car (gimp-drawable-has-alpha layer)))
		    (sel (car (gimp-selection-is-empty image)))
		    (layer-name (car (gimp-drawable-get-name layer)))
		    (keep-selection keep-selection-in)
			(selection 0)
			
        )
		
	(gimp-context-set-default-colors)

	;;;;scale image to given area if required	
	(gimp-image-scale image 
		(max 1 (min 262144 (round (* width (sqrt (/ area (* width height)))))))
		(max 1 (min 262144 (round (* height (sqrt (/ area (* width height))))))))
	(set! width (car (gimp-image-width image)))
	(set! height (car (gimp-image-height image)))
	
	
	(if (= alpha FALSE) (gimp-layer-add-alpha layer))
	
;;;;check that a selection was made if not make one	
	(if (= sel TRUE) (set! keep-selection FALSE))
	(if (= sel TRUE) (gimp-selection-layer-alpha layer))
	
	(script-fu-distress-selection image 
	                              layer 
								  127       ;Threshold (bigger 1<-->255 smaller)
								  8         ;Spread (8 0 1000 1 10 0 1)
								  4         ;Granularity (1 is low) (4 1 25 1 10 0 1)
								  2         ;Smooth (2 1 150 1 10 0 1)
								  TRUE      ;Smooth horizontally TRUE
								  TRUE)     ;Smooth vertically TRUE
	
;;;;create selection-channel (gimp-selection-load selection)    
	(set! selection (car (gimp-selection-save image)))	
    (gimp-image-set-active-layer image layer)	
	
;;;;begin the script
;;;;create the fur layer	
	(if (= fur-color 0) (begin ;use new colors
	(set! fur-layer (car (gimp-layer-new image width height RGBA-IMAGE "Fur" 100 NORMAL-MODE)))
	(gimp-image-add-layer image fur-layer (car (gimp-image-get-layer-position image layer)))
	(gimp-edit-fill fur-layer BACKGROUND-FILL)
	(gimp-selection-layer-alpha fur-layer)
	(plug-in-solid-noise RUN-NONINTERACTIVE image fur-layer 0 0 0 1 motle-size motle-size)
	(gimp-threshold fur-layer motle 255)
	(gimp-by-color-select fur-layer '(255 255 255) 15 2 TRUE FALSE 0 FALSE)
	(gimp-context-set-foreground tint-color)
	(gimp-edit-fill fur-layer FOREGROUND-FILL)
	
	(if (> motle 35) (begin
	(gimp-by-color-select fur-layer '(0 0 0) 15 2 TRUE FALSE 0 FALSE)
	(gimp-context-set-foreground motle-color)
	(gimp-edit-fill fur-layer FOREGROUND-FILL)))
	(gimp-selection-none image)))
	
(if (= fur-color 1) (begin ;use existing colors
	(set! fur-layer (car (gimp-layer-copy layer 0)))
	(gimp-image-add-layer image fur-layer (car (gimp-image-get-layer-position image layer)))
	(gimp-selection-none image)))
	
	(gimp-selection-load selection)
	(gimp-selection-invert image)
	(gimp-edit-clear fur-layer)
	(gimp-selection-none image)
	
	(if (> blur-radius 0) (plug-in-gauss-iir2 1 image fur-layer blur-radius blur-radius))
	(plug-in-gimpressionist 1 image fur-layer "Furry")

;;;;Scale Image to it's original size;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    (gimp-image-scale-full image final-width final-height 2)
	(set! width (car (gimp-image-width image)))
	(set! height (car (gimp-image-height image)))

;;;;finish the script	
	(if (= conserve FALSE) (begin
	(set! layer (car (gimp-image-merge-down image fur-layer EXPAND-AS-NECESSARY)))))
	(gimp-image-set-active-layer image layer)
    (gimp-drawable-set-name layer layer-name)
    (if (= keep-selection TRUE) (gimp-selection-load selection))
	(gimp-image-remove-channel image selection)
	(if (and (= conserve FALSE) (= alpha FALSE)) (gimp-layer-flatten layer))	

	(gimp-displays-flush)
	(gimp-image-undo-group-end image)
	(gimp-context-pop)

 )
)















(script-fu-register "script-fu-fur-logo"
"Furry..."
"Create a Fur covered Logo"
"Graechan"
"Graechan - http://gimpchat.com"
"Mar 2013"
""
SF-ADJUSTMENT "Image width (pixels)" '(250 1 1000 1 10 0 1)
SF-ADJUSTMENT "Image height(pixels)" '(250 1 1000 1 10 0 1)
SF-TEXT "Text" "Furry"
SF-ADJUSTMENT "Letter Spacing" '(0 -100 100 1 5 0 0)
SF-ADJUSTMENT "Line Spacing" '(0 -100 100 1 5 0 0)
SF-FONT "Font" "Arial Heavy"
SF-ADJUSTMENT "Font size (pixels)" '(350 6 500 1 1 0 1)
SF-COLOR "Tint color" '(107 57 0)
SF-COLOR "Motle color" '(82 43 0)
SF-ADJUSTMENT "Motle Size" '(16 1 16 .1 1 1 0)
SF-ADJUSTMENT "Motle Amount" '(120 0 250 1 10 0 0)
SF-ADJUSTMENT "Softness" '(15 0 60 1 5 0 0)
SF-OPTION "Background Type" '("None" "Pattern" "Gradient" "Color")
SF-PATTERN "Pattern" "Pink Marble"
SF-COLOR "Background color" "Gray"
SF-GRADIENT "Background Gradient" "Abstract 3"
SF-TOGGLE "Keep the Layers" FALSE
)

(script-fu-register "script-fu-fur"
"Furry..."
"creates fur inside a selection or layer"
"Graechan"
"Graechan - http://gimpchat.com"
"Mar 2013"
"RGB*"
SF-IMAGE "image" 0
SF-DRAWABLE "drawable" 0
SF-OPTION "Fur Coloring" '("New Colors" "Existing")
SF-COLOR "Tint color" '(107 57 0)
SF-COLOR "Motle color" '(82 43 0)
SF-ADJUSTMENT "Motle Size" '(16 1 16 .1 1 1 0)
SF-ADJUSTMENT "Motle Amount" '(120 0 250 1 10 0 0)
SF-ADJUSTMENT "Softness" '(15 0 60 1 5 0 0)
SF-TOGGLE "Keep selection" FALSE
SF-TOGGLE "Keep the Layers" FALSE
)

(script-fu-menu-register "script-fu-fur-logo" "<Image>/File/Create/Logos")

(script-fu-menu-register "script-fu-fur" "<Image>/Filters/Alpha to Logo")
