; EnviroLogo
;
; Created by GnuTux 
; Comments directed to http://gimpchat.com or http://gimpscripts.com
; Support Thread: http://gimpchat.com/viewtopic.php?f=9&t=2851
;
; License: GPLv3
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;    GNU General Public License for more details.
;
;    To view a copy of the GNU General Public License
;    visit: http://www.gnu.org/licenses/gpl.html
;
; ------------
;| Change Log |
; ------------ 
; V0.9 - Beta 
;
; 
; Define the apply logo envirologo procedure
;
(define (apply-envirologo 
                             img                     ; Image
                             logo-layer              ; Input Layer
                             bumpmap-blur-radius     ; Bumpmap Blur Radius
                             bumpmap-invert          ; Bumpmap Invert Toggle
                             emap-name               ; Environment Map Name
                             material-shiny          ; Brightness 
                             map-type                ; Environment Map Type
                             paint-mode              ; Selected Paint Mode For Use WIth Blend Plug-in
                             blend-direction         ; Blend Direction
                             blend-shape             ; Blend Shape
                             emap-gradient           ; Selected Gradient For Environment Map
                             detail-level            ; Detail Level For Solid Noise Plug-in 
                             texturesizex            ; Drawable Width
                             texturesizey            ; Drawable Height 
                             blur-radius             ; Gaussian Blur Radius 
                             auto-hsv                ; Autostretch HSV Flag
                             turbulent)              ; Turbulance Flag
  (let* (
           (emap-img -1)        ; Environment Map Image
           (emap-drawable -1)   ; Environment Map Drawable 
           (bumptext-layer -1)  ; Bump Text Layer
           (bumpmap-layer -1)   ; Bumpmap Layer
           (copytext-layer -1)  ; Copy of Text layer
           (background -1)      ; Background Layer
           (saved-selection -1) ; Saved Selection
           (act-lay-pos -1)     ; Current Slected Layer Position
           (invert-bump FALSE)  ; Inverted Bump Map
           (image-height 0)     ; Image Height
           (image-width 0)      ; Image Width
           (xblend-start 0)     ; X Blend Starting Point
           (yblend-start 0)     ; X Blend Starting Point
           (xblend-end 0)       ; X Blend Ending Point
           (yblend-end 0)       ; X Blend Ending Point
           (emap-name-len)      ; Length of Emap Filename
           (emap-name-pos)      ; Position of Substring in Emap Filename
        )
;
; Save Active Layer Position + 1
; 
(set! act-lay-pos (+ (car (gimp-image-get-layer-position img logo-layer)) 1)) 

;
; Create Bump Map & Save As Layer
;
     (set! copytext-layer (car (gimp-layer-new-from-drawable logo-layer img))) ; Copy of Logo Layer
     (set! bumpmap-layer (car (gimp-layer-new-from-drawable logo-layer img)))  ; BG for bumpmap
     (gimp-image-add-layer img bumpmap-layer act-lay-pos)                      ; Add it to image
     (gimp-layer-set-name bumpmap-layer "Bump Map")                            ; Name bumpmap
     (gimp-edit-clear bumpmap-layer)                                           ; Clear Layer
     (gimp-selection-all img)                                                  ; Select Layer
     (gimp-context-set-foreground '(255 255 255))                              ; Color to White
     (gimp-edit-bucket-fill bumpmap-layer 0 0 100 0 0 0 0)                     ; Fill with color
     (gimp-selection-none img)                                                 ; No Selection
     (gimp-layer-set-visible bumpmap-layer TRUE)                               ; Turn on Bumpmap Layer    

     (set! bumptext-layer (car (gimp-layer-new-from-drawable logo-layer img))) ; Text for bumpmap
     (gimp-image-add-layer img bumptext-layer act-lay-pos)                     ; Add it to image
     (gimp-layer-set-name bumptext-layer "Bump Text")                          ; Name bumpmap
     (gimp-layer-set-visible bumptext-layer TRUE)                              ; Turn on Bumpmap Layer    
     (set! bumpmap-layer (car (gimp-image-merge-down img bumptext-layer 0)))   ; Merge Down Text
;
;  Gausian Blur REL
;
     (plug-in-gauss                    ; Gaussien blur the shadow (radius blur)
                1                      ; Non-interactive 
                img                    ; Image to apply blur 
                bumpmap-layer          ; Layer to apply blur
                bumpmap-blur-radius    ; Blur Radius x  
                bumpmap-blur-radius    ; Blue Radius y 
                1)                     ; Method (IIR=0 RLE=1)

;
; Invert Bumpmap Check
;

    (if (= bumpmap-invert TRUE)                     ; Invert Bumpmap? 
        (begin
          (gimp-invert bumpmap-layer)               ; Invert it
        )
     ) ; endif

     (gimp-layer-set-visible bumpmap-layer FALSE)   ; Turn off Bumpmap Layer    

;
; Load Environment Map If Specified
;
;
; Notes on strings: (substring "xyz" 0 3) returns xyz 
;                   (substring-equal? "png" "xyz.png" 4 7) returns true
;                   (string-length "ABC") returns 3
;
(set! emap-name-len (string-length emap-name))         ; Length of the emap Filename
(set! emap-name-pos (- (string-length emap-name) 3))   ; Length of the emap filename minus 3 (postition of file extension) 


(if (or (substring-equal? "png" emap-name emap-name-pos emap-name-len) ; Validity Check png
        (substring-equal? "PNG" emap-name emap-name-pos emap-name-len) ; Validity Check PNG
        (substring-equal? "jpg" emap-name emap-name-pos emap-name-len) ; Validity Check jpg
        (substring-equal? "JPG" emap-name emap-name-pos emap-name-len) ; Validity Check JPG
    ) 
      (begin
        (set! emap-img (car (gimp-file-load RUN-NONINTERACTIVE emap-name emap-name))) ; Load emap
        (set! emap-drawable (car (gimp-image-get-active-drawable emap-img)))          ; Emap Drawable 
      ) ;else
      (begin
;
;       Generate An Environment Map if one is not manually loaded 
;
        (set! emap-drawable (car (gimp-layer-new-from-drawable logo-layer img)))  ; Text for bumpmap
        (gimp-image-add-layer img emap-drawable 2)                                ; Add it to image
        (gimp-image-set-active-layer img emap-drawable)                           ; Make layer Active
        (gimp-layer-set-visible emap-drawable FALSE)                              ; Turn off emap Layer    
;
; Call Solid Noise Plug-in
;
      (plug-in-solid-noise 
                       1         ; Interactive
                     img         ; Input Image
           emap-drawable         ; Imput Drawable
                    TRUE         ; Tileable
               turbulent         ; Turbulent Noise
         (random 999999)         ; Random Seed
            detail-level         ; Detail Level
            texturesizex         ; Horizontal Texture Size
            texturesizey         ; Vertical Texture Size
      )

;
; Auto-stretch HSV
;
     (if (= auto-hsv TRUE)
         (begin  
           (plug-in-autostretch-hsv 1 img emap-drawable)
         )
     ) ;endif

;
; Gaussian Blur
;
     (if (> blur-radius 0)
        (begin  
            (plug-in-gauss                 
                        1     ; Non-interactive 
                      img     ; Image to apply blur 
            emap-drawable     ; Layer to apply blur
              blur-radius     ; Blur Radius x  
              blur-radius     ; Blue Radius y 
                        0     ; Method (IIR=0 RLE=1)
            )
        )
     ) ;endif


;
; Set Specified Gradient Active
;
(gimp-context-set-gradient emap-gradient)

;
; Environment Map Type: Topographical
;
(if (= map-type 0)
    (begin  
      (plug-in-gradmap 1 img emap-drawable)                 ; Map Gradient
      (gimp-layer-set-name emap-drawable "EnviroMap: Topo") ; Name it
     )
) ;endif

;
; Environment Map Type: Cloud
;
(if (or (> paint-mode 0) (= map-type 1))
    (begin  

     (set! image-height (car (gimp-drawable-height emap-drawable)))     ; Get Height 
     (set! image-width (car (gimp-drawable-width emap-drawable)))       ; Get Width

;
; Calculate Gradient Blend Start & End Points
;

      (cond ((= blend-direction 0)         ; Top-Bottom 
          (set! xblend-start 0)            ; X Blend Starting Point
          (set! yblend-start 0)            ; Y Blend Starting Point
          (set! xblend-end 0)              ; X Blend Ending Point
          (set! yblend-end image-height)   ; Y Blend Ending Point
          )
          ((= blend-direction 1)           ; Bottom-Top
          (set! xblend-start 0)            ; X Blend Starting Point
          (set! yblend-start image-height) ; Y Blend Starting Point
          (set! xblend-end 0)              ; X Blend Ending Point
          (set! yblend-end 0)              ; Y Blend Ending Point
          )
          ((= blend-direction 2)           ; Left-Right
          (set! xblend-start 0)            ; X Blend Starting Point
          (set! yblend-start 0)            ; Y Blend Starting Point
          (set! xblend-end image-width)    ; X Blend Ending Point
          (set! yblend-end 0)              ; Y Blend Ending Point
          )
          ((= blend-direction 3)           ; Right-Left
          (set! xblend-start image-width)  ; X Blend Starting Point
          (set! yblend-start 0)            ; Y Blend Starting Point
          (set! xblend-end 0)              ; X Blend Ending Point
          (set! yblend-end 0)              ; Y Blend Ending Point
          )
          ((= blend-direction 4)           ; Diag-Top-Left
          (set! xblend-start 0)            ; X Blend Starting Point
          (set! yblend-start 0)            ; Y Blend Starting Point
          (set! xblend-end image-width)    ; X Blend Ending Point
          (set! yblend-end image-height)   ; Y Blend Ending Point
          )
          ((= blend-direction 5)           ; Diag-Top-Right
          (set! xblend-start image-width)  ; X Blend Starting Point
          (set! yblend-start 0)            ; Y Blend Starting Point
          (set! xblend-end 0)              ; X Blend Ending Point
          (set! yblend-end image-height)   ; Y Blend Ending Point
          )
          ((= blend-direction 6)           ; Diag-Bottom-Left
          (set! xblend-start 0)            ; X Blend Starting Point
          (set! yblend-start image-height) ; Y Blend Starting Point
          (set! xblend-end image-width)    ; X Blend Ending Point
          (set! yblend-end 0)              ; Y Blend Ending Point
          )
          ((= blend-direction 7)           ; Diag-Bottom-Right
          (set! xblend-start image-width)  ; X Blend Starting Point
          (set! yblend-start image-height) ; Y Blend Starting Point
          (set! xblend-end 0)              ; X Blend Ending Point
          (set! yblend-end 0)              ; Y Blend Ending Point
          )
;          (else
;                 ; For later use.. 
;          )
       ) ;end cond
;
; Check Paint Mode
;

     (if (= paint-mode 0)
            (begin  
              (set! paint-mode 4)   ; Normal Makes No Sense For Cloud Map So Set To Screen As Default
            )
      ) ;endif

             (gimp-edit-blend        ; Blend (Gradient)
                      emap-drawable  ; Drawable - (The affected drawable)
                        CUSTOM       ; Int32 - Blend Type (FG-BG-RGB-MODE (0))
                        paint-mode   ; Int32 - Paint Mode (NORMAL-MODE (0)) 
                        blend-shape  ; Int32 - Gradient Type (LINEAR (0))
                        100          ; Float - Opacity (0 - 100)
                        0            ; Float - Offset ( >= 0) 
                        0            ; Int32 - Repeat (NONE (0))
                        FALSE        ; Int32 - Reverse (TRUE or FALSE)
                        TRUE         ; Int32 - Supersample (TRUE or FALSE)
                        3            ; Int32 - Supersampling Recursion  Dept (1 - 9)
                        0.20         ; Float - Supersampling threshold (0 <= 4)
                        TRUE         ; Int32 - Dither (TRUE or FALSE)
                        xblend-start ; Int32 - X Blend Starting Point
                        yblend-start ; Int32 - Y Blend Starting Point
                        xblend-end   ; Int32 - X Blend Ending Point  
                        yblend-end   ; Int32 - Y Blend Ending Point
             ) ; End Blend

             (gimp-layer-set-name emap-drawable "EnviroMap: Cloud")          ; Name Environment Map
     )
) ;endif

;
; Ensure Environment Map Does Not Have An Alpha Channel So Flatten
;
(gimp-layer-flatten emap-drawable)    


   ) ;End Else Begin

) ; Endif (of emap render)

;
; Run lighting filter with environment map and bump map
;
(gimp-image-set-active-layer img logo-layer)   ; Make Text layer Active

    (plug-in-lighting 
                      1                ; Interactive (0), non-interactive (1)
                      img              ; Input image
                      logo-layer       ; Input drawable
                      bumpmap-layer    ; Bumpmap drawable (set to 0 if disabled)
                      emap-drawable    ; Environmentmap drawable (set to 0 if disabled)
                      TRUE             ; Enable bumpmapping (TRUE/FALSE)
                      TRUE             ; Enable envmapping (TRUE/FALSE)
                      0                ; Type of mapping (0=linear,1=log, 2=sinusoidal, 3=spherical)
                      0                ; Type of lightsource (0=point,1=directional,3=spot,4=none)
                      '(255 255 255)   ; Lightsource color (r,g,b)
                      0.85             ; Lightsource position x
                      1                ; Lightsource position y
                      1                ; Lightsource position z
                     -0.90             ; Lightsource direction x
                     -1                ; Lightsource direction y
                      1                ; Lightsource direction z
                      0.20             ; Material ambient intensity (0.00..1) (Glowing)
                      1                ; Material diffuse intensity (0..1) (Intensity
                      50               ; Material diffuse reflectivity (0..1) (Bright)
                      material-shiny   ; Material specular reflectivity (0..1) (Shiny)
                      30               ; Material highlight (0..->) note: it's expotential (Polished)
                      TRUE             ; Apply antialiasing (TRUE/FALSE)
                      FALSE            ; Create a new image (TRUE/FALSE)
                      FALSE)           ; Make background transparent (TRUE/FALSE)
;
; Copy of the text
;
     (gimp-image-add-layer img copytext-layer 1)            ; Add it to image
     (gimp-layer-set-name copytext-layer "Logo Copy")       ; Name Copy 
     (gimp-image-lower-layer-to-bottom img copytext-layer)  ; Move to bottom
     (gimp-layer-set-visible copytext-layer FALSE)          ; Turn off copy
     (gimp-image-set-active-layer img logo-layer)           ; Make layer Active
     (gimp-layer-set-visible logo-layer TRUE)               ; Ensure Logo layer is on

;
; Selection Check
;

;    (if (= (car (gimp-selection-is-empty img)) TRUE)      ; Check for a selection 
;        (begin
;          (gimp-selection-layer-alpha logo-layer)         ; Select alpha to logo If there isn't one
;        )
;     ) ; endif

 ); endlet
) ; return (from apply-envirologo) 

;
; Define alpha to selection procedure
;
(define (script-fu-envirologo-alpha 
                   img                     ; Image
                   logo-layer              ; Input layer
                   bumpmap-blur-radius     ; Bumpmap Blur Radius
                   bumpmap-invert          ; Bumpmap Invert Toggle
                   emap-name               ; Emap Name
                   material-shiny          ; Brightness 
                   map-type                ; Environment Map Type
                   paint-mode              ; Selected Paint Mode For Use With Blend Plug-in
                   blend-direction         ; Blend Direction
                   blend-shape             ; Blend Shape
                   emap-gradient           ; Selected Gradient For Environment Map
                   detail-level            ; Detail Level For Solid Noise Plug-in 
                   texturesizex            ; Drawable Width
                   texturesizey            ; Drawable Height 
                   blur-radius             ; Gaussian Blur Radius 
                   auto-hsv                ; Autostretch HSV Flag
                   turbulent)              ; Turbulance Flag

  (let* (
          (alpha2logo 1) ; 0 - Text mode , 1 - Alpha mode
        )

;
; Save current GIMP context
;
    (gimp-context-push)               ; Push context onto stack
    (gimp-image-undo-group-start img) ; Begin undo group
;
; Call apply logo procedure  
;
    (apply-envirologo 
                 img                     ; Image
                 logo-layer              ; Input layer
                 bumpmap-blur-radius     ; Bumpmap Blur Radius
                 bumpmap-invert          ; Bumpmap Invert Toggle
                 emap-name               ; Emap Name
                 material-shiny          ; Brightness 
                 map-type                ; Environment Map Type
                 paint-mode              ; Selected Paint Mode For Use WIth Blend Plug-in
                 blend-direction         ; Blend Direction
                 blend-shape             ; Blend Shape
                 emap-gradient           ; Selected Gradient For Environment Map
                 detail-level            ; Detail Level For Solid Noise Plug-in 
                 texturesizex            ; Drawable Width
                 texturesizey            ; Drawable Height 
                 blur-radius             ; Gaussian Blur Radius 
                 auto-hsv                ; Autostretch HSV Flag
                 turbulent)              ; Turbulance Flag

    (gimp-image-undo-group-end img) ; End undo group
    (gimp-context-pop)              ; Pop context off stack
    (gimp-displays-flush)           ; Flush display

  ) ;endlet
) ; return  

;
; Register logo to alpha procedure
;
(script-fu-register "script-fu-envirologo-alpha"
                    _"_EnviroLogo..."
                    _"Create selected logo"
                    "GnuTux - http://gimpchat.com"
                    "GnuTux - GPLv3"
                    "08-2013"
                    "RGBA"
                    SF-IMAGE      "Image"                   0
                    SF-DRAWABLE   "Drawable"                0
                    SF-ADJUSTMENT _"Bumpmap Blur(Depth)"    '(3 1 25 1 1 0 0)
                    SF-TOGGLE     _"Invert Bumpmap"         FALSE
                    SF-FILENAME   _"Select Environment Map" ""
                    SF-ADJUSTMENT _"Brightness"             '(.50 .00 1.00 .01 .05 2 0)
                    SF-OPTION     _"Map Type"                 '("Topographical" "Cloud")
                    SF-OPTION      "Blending Mode"            '("Normal" "Dissolve" "Behind" "Multiply" "Screen" "Overlay" "Difference" "Addition" "Subtract" "Darken" "Lighten" "Hue" "Saturation" "Color" "Value" "Divide" "Dodge" "Burn" "Hard Light" "Soft Light" "Grain Extract" "Grain Merge")
                    SF-OPTION     _"Blend Direction"          '("Top-Botton" "Bottom-Top" "Left-Right" "Right-Left" "Diag-Top-Left" "Diag-Top-Right" "Diag-Bottom-Left" "Diag-Bottom-Right")
                    SF-OPTION     _"Blend Shape"              '("Linear""Bilinear" "Radial" "Square" "Conical-Symmetric" "Conical-Asymmetric" "Shapeburst-Angular" "Shapburst-Spherical" "Shapeburst-Dimpled" "Spiral-CW" "Spiral-CCW")
                    SF-GRADIENT   _"Select Gradient"          "Golden"
                    SF-ADJUSTMENT _"Detail Level"             '(1 0 3 1 5 0 0)
                    SF-ADJUSTMENT _"Horizontal Texture Size"  '(2.8 1 5 .1 .5 1 0)
                    SF-ADJUSTMENT _"Vertical Texture Size"    '(2.8 1 5 .1 .5 1 0)
                    SF-ADJUSTMENT _"Blur Radius"              '(5 0 30 1 5 0 0)
                    SF-TOGGLE     _"Autostretch HSV"          TRUE
                    SF-TOGGLE     _"Turbulent Noise"          FALSE
) ;end register


(script-fu-menu-register "script-fu-envirologo-alpha"
                         "<Image>/Filters/Alpha to Logo")

;
; Define logo text procedure
;
(define (script-fu-envirologo 
                              text                    ; Text Later
                              font                    ; Selected Font
                              size                    ; Text Size
                              spacing                 ; Letter Spacing
                              bumpmap-blur-radius     ; Bumpmap Blur Radius 
                              bumpmap-invert          ; Bumpmap invert Toggle
                              emap-name               ; Environment Map Name
                              material-shiny          ; Brightness
                              map-type                ; Environment Map Type
                              paint-mode              ; Selected Paint Mode For Use WIth Blend Plug-in
                              blend-direction         ; Blend Direction
                              blend-shape             ; Blend Shape
                              emap-gradient           ; Selected Gradient For Environment Map
                              detail-level            ; Detail Level For Solid Noise Plug-in 
                              texturesizex            ; Drawable Width
                              texturesizey            ; Drawable Height 
                              blur-radius             ; Gaussian Blur Radius 
                              auto-hsv                ; Autostretch HSV Flag
                              turbulent)              ; Turbulance Flag
 (let* (
          (img -1)                                 ; Declare and Init img
          (text-layer -1)                          ; Declare and init text-layer
          (logo-layer -1)                          ; Declare and init logo-layer 
          (alpha2logo 0)			               ; 0 - Text mode , 1 - Alpha mode
       )
  
  (gimp-context-push)                              ; Push context onto stack
  (set! img (car (gimp-image-new 128 128 RGB)))    ; Create a new image

;
; Original Text Layer (keep untouched)
;
   (gimp-context-set-foreground '(0 0 0))                   ; Set FG to logo color
   (set! text-layer (car (gimp-text-fontname img -1 0 0 text 40 TRUE size PIXELS font))) ; Create text layer
   (gimp-text-layer-set-letter-spacing text-layer spacing)  ; Set Letter Spacing
   (script-fu-util-image-resize-from-layer img text-layer)  ; Logo layer to image size
   (gimp-desaturate text-layer)                             ; Desat discards text date 
   (gimp-image-undo-group-start img)                        ; Begin undo group
                                                            
;
; Call the logo envirologo main procedure 
;
  (apply-envirologo
               img                     ; Image
               text-layer              ; Text Layer 
               bumpmap-blur-radius     ; Bumpmap Radius
               bumpmap-invert          ; Bumpmap Invert Toggle
               emap-name               ; Environment Map Name
               material-shiny          ; Brightness 
               map-type                ; Environment Map Type
               paint-mode              ; Selected Paint Mode For Use WIth Blend Plug-in
               blend-direction         ; Blend Direction
               blend-shape             ; Blend Shape
               emap-gradient           ; Selected Gradient For Environment Map
               detail-level            ; Detail Level For Solid Noise Plug-in 
               texturesizex            ; Drawable Width
               texturesizey            ; Drawable Height 
               blur-radius             ; Gaussian Blur Radius 
               auto-hsv                ; Autostretch HSV Flag
               turbulent)              ; Turbulance Flag

    (gimp-selection-none img)          ; Clear selection
    (gimp-image-undo-group-end img)    ; End undo group
    (gimp-context-pop)                 ; Pop context off stack

    (gimp-display-new img)             ; Show the image

 ) ; endlet
) ; return

;
; Register the script
;    
(script-fu-register "script-fu-envirologo"
                    _"_EnviroLogo..."
                    _"Create logo"
                    "GnuTux - http://gimpchat.com"
                    "GnuTux - GPLv3"
                    "08-2013"
                    ""
                    SF-STRING     _"Text"                  "GIMP"
                    SF-FONT       _"Font"                  "Serif Bold"
                    SF-ADJUSTMENT _"Font size (pixels)"    '(220 2 1000 1 10 0 0)
                    SF-ADJUSTMENT _"Letter Spacing"        '(-8 -50 50 1 5 0 0)
                    SF-ADJUSTMENT _"Bumpmap Blur (Depth)"  '(3 1 25 1 1 0 0)
                    SF-TOGGLE     _"Invert Bumpmap"         FALSE
                    SF-FILENAME   _"Environment Map (png/jpg)"  "none"
                    SF-ADJUSTMENT _"Brightness"            '(.50 .00 1.00 .01 .05 2 0)
                    SF-OPTION     _"Map Type"                 '("Topographical" "Cloud")
                    SF-OPTION      "Blending Mode"            '("Normal" "Dissolve" "Behind" "Multiply" "Screen" "Overlay" "Difference" "Addition" "Subtract" "Darken" "Lighten" "Hue" "Saturation" "Color" "Value" "Divide" "Dodge" "Burn" "Hard Light" "Soft Light" "Grain Extract" "Grain Merge")
                    SF-OPTION     _"Blend Direction"          '("Top-Botton" "Bottom-Top" "Left-Right" "Right-Left" "Diag-Top-Left" "Diag-Top-Right" "Diag-Bottom-Left" "Diag-Bottom-Right")
                    SF-OPTION     _"Blend Shape"              '("Linear""Bilinear" "Radial" "Square" "Conical-Symmetric" "Conical-Asymmetric" "Shapeburst-Angular" "Shapburst-Spherical" "Shapeburst-Dimpled" "Spiral-CW" "Spiral-CCW")
                    SF-GRADIENT   _"Select Gradient"          "Golden"
                    SF-ADJUSTMENT _"Detail Level"             '(1 0 3 1 5 0 0)
                    SF-ADJUSTMENT _"Horizontal Texture Size"  '(2.8 1 5 .1 .5 1 0)
                    SF-ADJUSTMENT _"Vertical Texture Size"    '(2.8 1 5 .1 .5 1 0)
                    SF-ADJUSTMENT _"Blur Radius"              '(5 0 30 1 5 0 0)
                    SF-TOGGLE     _"Autostretch HSV"          TRUE
                    SF-TOGGLE     _"Turbulent Noise"          FALSE

) ; end register


(script-fu-menu-register "script-fu-envirologo"
                         _"<Image>/File/Create/Logos")
